@@ -1153,82 +1153,8 @@ sub new_user_amazon {
    if ($cleanup) {
       my $fullauto_inst=get_fullauto_instance();
       my $i=$fullauto_inst->{InstanceId};
-      my $getownerid='aws ec2 describe-security-groups --filters '.
-                     'Name="description",Values="default VPC security group"';
-      ($hash,$output,$error)=run_aws_cmd($getownerid);
-      if ($error) {
-         print "Kali Linux Instruction Set aws cmd ERROR!: $error at Line",
-            __LINE__,"\n";
-         Net::FullAuto::FA_Core::cleanup();
-      }
-      my $getkaliimages=
-            'aws ec2 describe-images --filters Name=owner-id,Values='.
-            $hash->{SecurityGroups}->[0]->{OwnerId};
-      ($hash,$output,$error)=run_aws_cmd($getkaliimages);
-      if (-1<$#{$hash->{Images}}) {
-         foreach my $image (@{$hash->{Images}}) {
-            next if -1==index $image->{Name},'kali-kali-amd';
-            ($hash,$output,$error)=run_aws_cmd(
-               "aws ec2 deregister-image --image-id ".$image->{ImageId});
-            if ($error) {
-               print "Kali Linux Instruction Set aws cmd ERROR!: ",
-                  "$error at Line",__LINE__,"\n";
-               Net::FullAuto::FA_Core::cleanup();
-            }
-            ($hash,$output,$error)=run_aws_cmd(
-               "aws ec2 delete-snapshot --snapshot-id ".
-               $image->{BlockDeviceMappings}->[0]->{Ebs}->{SnapshotId});
-            if ($error) {
-               print "Kali Linux Instruction Set aws cmd ERROR!: ",
-                  "$error at Line",__LINE__,"\n";
-               Net::FullAuto::FA_Core::cleanup();
-            }
-         }
-      }
-      my $t="aws ec2 describe-tags";
-      my ($hash,$output,$error)=('','','');
-      ($hash,$output,$error)=Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($t);
-      my @kill_these_instances=();
-      foreach my $tag (@{$hash->{Tags}}) {
-         $t="aws ec2 describe-instance-status --instance-id $tag->{ResourceId}";
-         if ($tag->{Key} eq 'Name' && $tag->{Value}=~/FullAuto/) {
-            ($hash,$output,$error)=run_aws_cmd($t);
-            push @kill_these_instances, $tag->{ResourceId} if
-               (-1<$#{$hash->{InstanceStatuses}}) &&
-               $hash->{InstanceStatuses}->[0]->{InstanceState}->{Name}
-               eq 'running';
-         } elsif ($tag->{Key} eq 'FullAuto') {
-            ($hash,$output,$error)=run_aws_cmd($t);
-            unshift @kill_these_instances, $tag->{ResourceId} if
-               (-1<$#{$hash->{InstanceStatuses}}) &&
-               $hash->{InstanceStatuses}->[0]->{InstanceState}->{Name}
-               eq 'running';
-         }
-
-      }
-      $t="aws s3api list-buckets";
+      $t="aws ec2 terminate-instances --instance-id $i";
       ($hash,$output,$error)=run_aws_cmd($t);
-      foreach my $bucket (@{$hash->{Buckets}}) {
-         if (-1<index $bucket->{Name},$i) {
-            my $b=$bucket->{Name};
-            $t="aws s3api list-objects --bucket $b --query ".
-               "'Contents[].{Key: Key}'";
-            ($hash,$output,$error)=run_aws_cmd($t);
-            if ($output) {
-               chomp $output;
-               $output="{ \"Objects\": $output, \"Quiet\": false }";
-               $output="'".$output."'";
-               $t="aws s3api delete-objects --bucket $b --delete $output";
-               ($hash,$output,$error)=run_aws_cmd($t);
-            }
-            $t="aws s3api delete-bucket --bucket $b";
-            ($hash,$output,$error)=run_aws_cmd($t);
-         }
-      }
-      foreach my $instance (@kill_these_instances) {
-         $t="aws ec2 terminate-instances --instance-id $instance";
-         ($hash,$output,$error)=run_aws_cmd($t);
-      }
       Net::FullAuto::FA_Core::cleanup();
    }
    my $banner=<<'END';
